pub enum StreamResult {
Complete(usize),
Dropped,
Cancelled,
}Available on crate feature
async only.Expand description
Result of a StreamWriter::write or StreamReader::read operation,
yielded by the StreamWrite or StreamRead futures.
Variants
Complete(usize)
The provided number of values were successfully transferred.
For writes this is how many items were written, and for reads this is how many items were read.
Dropped
No values were written, the other end has dropped its handle.
Cancelled
No values were written, the operation was cancelled.