Module resource

Module resource 

Helper traits, types, and utilities for managing resources in the component model.

Traits

Resource
A trait implemented by all resources that a component might export.
ResourceRep
A trait used to define how to access the underlying data T from an in-memory representation.